#!/usr/bin/env python

"""This computes a Monte-Carlo estimate of a t-like statistic:
	(hypothesis-median)/quasi_Inter_Quartile_Range,
	and reports the symmetric 95% confidence interval.
"""

import random
import math

Trials = 100000
N = 7
P = 0.95

def median(x):
	"""We compute the median in the obvious way:
	sorting the data, then taking the middle point
	or (if there an even number of points) the average
	of the two midpoints.
	"""
	x.sort()
	n = len(x)
	if n%2 == 1:
		return x[n/2]
	return 0.5*(x[(n-1)/2] + x[n/2])


def qIQR(x):
	"""This is not quite the inter-quartile range.  It's simpler.
	Just count the points, divide by 4 (rounding down), and
	knock that many points off the top and bottom.
	Then, subtract the smallest remaining point from the largest
	remaining point.
	"""
	x.sort()
	n = len(x)
	trim = n // 4
	return x[n-1-trim] - x[trim]


if __name__ == '__main__':
	samples = []
	for i in range(Trials):
		x = [random.normalvariate(0.0, 1.0) for k in range(N)]
		med = median(x)
		qiqr = qIQR(x)
		t = med/(qiqr/math.sqrt(N))
		samples.append(abs(t))
	samples.sort()
	m = int(round(P*N))
	print samples[m]
